@@ -606,11 +606,15 @@ file_info_from_message (SoupMessage *msg,
       icon = g_content_type_get_icon (text);
       g_file_info_set_icon (info, icon);
       g_object_unref (icon);
+
+      icon = g_content_type_get_symbolic_icon (text);
+      g_file_info_set_symbolic_icon (info, icon);
+      g_object_unref (icon);
     }
 
 
-  text = soup_message_headers_get (msg->response_headers,
-                                   "Last-Modified");
+  text = soup_message_headers_get_one (msg->response_headers,
+                                       "Last-Modified");
   if (text)
     {
       SoupDate *sd;
@@ -626,8 +630,8 @@ file_info_from_message (SoupMessage *msg,
     }
 
 
-  text = soup_message_headers_get (msg->response_headers,
-                                   "ETag");
+  text = soup_message_headers_get_one (msg->response_headers,
+                                       "ETag");
   if (text)
     {
       g_file_info_set_attribute_string (info,
