@@ -39,6 +39,7 @@ typedef struct {
   char *stable_name;
   char *x_content_types;
   char *icon;
+  char *symbolic_icon;
   char *prefered_filename_encoding;
   gboolean user_visible;
   char *default_location;
@@ -187,6 +188,7 @@ vfs_mount_free (VfsMount *mount)
   g_free (mount->stable_name);
   g_free (mount->x_content_types);
   g_free (mount->icon);
+  g_free (mount->symbolic_icon);
   g_free (mount->fuse_mountpoint);
   g_free (mount->prefered_filename_encoding);
   g_free (mount->default_location);
@@ -199,19 +201,20 @@ vfs_mount_free (VfsMount *mount)
 
 
 /* Keep in sync with dbus-interfaces.xml */
-#define VFS_MOUNT_ARRAY_DBUS_STRUCT_TYPE "a(sosssssbay(aya{sv})ay)"
+#define VFS_MOUNT_ARRAY_DBUS_STRUCT_TYPE "a(sossssssbay(aya{sv})ay)"
 #define VFS_MOUNTABLE_ARRAY_DBUS_STRUCT_TYPE "a(ssasib)"
 
 static GVariant *
 vfs_mount_to_dbus (VfsMount *mount)
 {
-  return g_variant_new ("(sosssssb^ay@(aya{sv})^ay)",
+  return g_variant_new ("(sossssssb^ay@(aya{sv})^ay)",
                         mount->dbus_id,
                         mount->object_path,
                         mount->display_name,
                         mount->stable_name,
                         mount->x_content_types,
                         mount->icon,
+                        mount->symbolic_icon,
                         mount->prefered_filename_encoding,
                         mount->user_visible,
                         (fuse_available && mount->fuse_mountpoint) ? mount->fuse_mountpoint : "",
@@ -286,8 +289,12 @@ dbus_mount_reply (GVfsDBusMountable *proxy,
            g_error_matches (error, G_DBUS_ERROR, G_DBUS_ERROR_SERVICE_UNKNOWN)) &&
            !data->spawned)
         spawn_mount (data);
+      else if (g_error_matches (error, G_IO_ERROR,
+                                G_IO_ERROR_ALREADY_MOUNTED))
+        mount_finish (data, NULL);
       else
         {
+          g_dbus_error_strip_remote_error (error);
           g_warning ("dbus_mount_reply: Error from org.gtk.vfs.Mountable.mount(): %s", error->message);
           mount_finish (data, error);
           g_error_free (error);
@@ -350,18 +357,33 @@ spawn_mount_handle_spawned (GVfsDBusSpawner *object,
                             GDBusMethodInvocation *invocation,
                             gboolean arg_succeeded,
                             const gchar *arg_error_message,
+                            guint arg_error_code,
                             gpointer user_data)
 {
   MountData *data = user_data;
-  GError *error;
+  GError *error = NULL;
 
   g_dbus_interface_skeleton_unexport (G_DBUS_INTERFACE_SKELETON (data->spawner));
-  
+
   if (!arg_succeeded)
     {
-      g_set_error_literal (&error, G_IO_ERROR, G_IO_ERROR_FAILED, arg_error_message);
-      mount_finish (data, error);
-      g_error_free (error);
+      if (arg_error_code == G_IO_ERROR_ALREADY_MOUNTED &&
+          data->mountable->dbus_name != NULL)
+        {
+          /* This means the spawn failed since someone already owned the name.
+             It might not strictly be mounted yet, as the mount might not
+             be registred yet. So, to avoid races we ask the new owner of
+             the name to mount. It'll typically return an ALREADY_MOUNTED
+             error which we treat as success.
+          */
+          mountable_mount_with_name (data, data->mountable->dbus_name);
+        }
+      else
+        {
+          g_set_error_literal (&error, G_IO_ERROR, arg_error_code, arg_error_message);
+          mount_finish (data, error);
+          g_error_free (error);
+        }
     }
   else
     {
@@ -574,6 +596,7 @@ handle_register_mount (GVfsDBusMountTracker *object,
                        const gchar *arg_stable_name,
                        const gchar *arg_x_content_types,
                        const gchar *arg_icon,
+                       const gchar *arg_symbolic_icon,
                        const gchar *arg_prefered_filename_encoding,
                        gboolean arg_user_visible,
                        GVariant *arg_mount_spec,
@@ -611,6 +634,7 @@ handle_register_mount (GVfsDBusMountTracker *object,
       mount->stable_name = g_strdup (arg_stable_name);
       mount->x_content_types = g_strdup (arg_x_content_types);
       mount->icon = g_strdup (arg_icon);
+      mount->symbolic_icon = g_strdup (arg_symbolic_icon);
       mount->prefered_filename_encoding = g_strdup (arg_prefered_filename_encoding);
       mount->user_visible = arg_user_visible;
       mount->dbus_id = g_strdup (id);
@@ -624,16 +648,11 @@ handle_register_mount (GVfsDBusMountTracker *object,
 
       if (arg_user_visible)
         {
-          char *fs_name;
-          
-          /* Keep in sync with fuse daemon */
-          fs_name = g_uri_escape_string (mount->stable_name, "+@#$., ", TRUE);
-          
           /* Use the old .gvfs location as fallback, not .cache/gvfs */
           if (g_get_user_runtime_dir() == g_get_user_cache_dir ())
-            mount->fuse_mountpoint = g_build_filename (g_get_home_dir(), ".gvfs", fs_name, NULL);
+            mount->fuse_mountpoint = g_build_filename (g_get_home_dir(), ".gvfs", mount->stable_name, NULL);
           else
-            mount->fuse_mountpoint = g_build_filename (g_get_user_runtime_dir(), "gvfs", fs_name, NULL);
+            mount->fuse_mountpoint = g_build_filename (g_get_user_runtime_dir(), "gvfs", mount->stable_name, NULL);
         }
       
       mounts = g_list_prepend (mounts, mount);
